@@ -1,13 +1,14 @@
 from django.apps import apps
 from django.utils.module_loading import import_string
 
-def get_meta(request):
+
+def get_meta(request, return_default=True):
     # importing models
     Meta = import_string('pagemeta.models.Meta')
     MetaForPage = apps.get_model('pagemeta.MetaForPage')
     
     # getting meta tag from url
-    meta = MetaForPage.get_meta_from_current_url()
+    meta = MetaForPage.get_from_current_url()
     if meta:
         return Meta.from_meta_for_page(meta)
 
@@ -15,13 +16,17 @@ def get_meta(request):
     if hasattr(request, '_custom_meta') and request._custom_meta:
         return request._custom_meta
 
-    # checking and returning default meta tag
-    default_meta = Meta.from_meta_for_page(MetaForPage.get_default_meta())
-    if default_meta:
-        return default_meta
+    if return_default:
+        # checking and returning default meta tag
+        default_meta = Meta.get_default()
+        if default_meta:
+            return default_meta
 
     # returning empty string
-    return ''
+    return Meta.none()
+
+def get_meta_exact(request):
+    return get_meta(request, return_default=False)
 
 def set_meta(request, meta):
     request._custom_meta = meta
\ No newline at end of file
